@@ -10,7 +10,7 @@ use strict;
 use warnings;
 no warnings 'recursion'; # Disable the "deep recursion" warning
 
-our $VERSION = '0.48_001';
+our $VERSION = '0.48_002';
 
 # we are not overloaded, but we want to check if other objects are
 require overload;
@@ -20,11 +20,15 @@ require Future::Exception;
 our @CARP_NOT = qw( Future::Utils );
 
 BEGIN {
-   # TODO: A later version of this file will likely check for a Future::XS
-   # module and use that. For now we'll just always take the PP base.
-   require Future::PP;
-   our @ISA = qw( Future::PP );
-   *DEBUG = \&Future::PP::DEBUG;
+   if( !$ENV{PERL_FUTURE_NO_XS} and eval { require Future::XS } ) {
+      our @ISA = qw( Future::XS );
+      *DEBUG = \&Future::XS::DEBUG;
+   }
+   else {
+      require Future::PP;
+      our @ISA = qw( Future::PP );
+      *DEBUG = \&Future::PP::DEBUG;
+   }
 }
 
 our $TIMES = DEBUG || $ENV{PERL_FUTURE_TIMES};
@@ -548,6 +552,8 @@ If the future was cancelled or is not yet ready an exception is thrown.
 
 =cut
 
+*AWAIT_RESULT = *AWAIT_GET = sub { shift->result };
+
 =head2 get
 
    @result = $future->get
@@ -562,7 +568,7 @@ the result returned as above.
 
 =cut
 
-*AWAIT_RESULT = *AWAIT_GET = sub { shift->result };
+*AWAIT_WAIT = sub { shift->get };
 
 =head2 await
 
